import sqlite3
import xml.sax 

class TravahoHandler(xml.sax.ContentHandler):
    def __init__(self):
        self.superieur_id = ['NULL']
        self.sql_attr_name = None
        self.sql_attrs = dict()
        self.conn = None

    def startDocument(self):
        self.conn = sqlite3.connect('travaho-import-sax.db')
        c = self.conn.cursor()
        c.execute('DROP TABLE IF EXISTS EMPLOYE')
        c.execute('''
        CREATE TABLE IF NOT EXISTS EMPLOYE (
           ID       INTEGER PRIMARY KEY AUTOINCREMENT, 
           NOM      TEXT,
           PRENOM   TEXT,
           EMBAUCHE DATE,
           DEPT     TEXT,
           VILLE    TEXT,
           SALAIRE  FLOAT,
           ID_SUPERIEUR INT REFERENCES EMPLOYE(ID)
        );
        ''');

    def startElement(self, xml_name, xml_attrs):
        if xml_name == 'travail':
            pass
        elif xml_name == 'employe':
            self.sql_attr_name = None
            self.sql_attrs = {
                'nom' : '',
                'prenom' : '',
                'embauche' : '',
                'dept' : '',
                'ville' : '',
                'salaire' : ''}
        elif xml_name == 'departament':
            self.sql_attrs['dept'] += xml_attrs['nom']
            self.sql_attrs['ville'] += xml_attrs['ville']
        elif xml_name in ['nom', 'prenom', 'embauche', 'salaire']:
            self.sql_attr_name = xml_name
        else:
            pass

    def characters(self, text):
        if self.sql_attr_name is not None:
            self.sql_attrs[self.sql_attr_name] += text

    def endElement(self, xml_name):
        if xml_name == 'departament':
            c = self.conn.cursor()
            c.execute('INSERT INTO EMPLOYE(NOM,PRENOM,EMBAUCHE,\
                       DEPT,VILLE,SALAIRE,ID_SUPERIEUR) VALUES \
                       (?,?,?,?,?,?,?)',
                      (self.sql_attrs['nom'].strip(),
                       self.sql_attrs['prenom'].strip(),
                       self.sql_attrs['embauche'].strip(),
                       self.sql_attrs['salaire'].strip(),
                       self.sql_attrs['dept'].strip(),
                       self.sql_attrs['ville'].strip(),
                       self.superieur_id[-1]));
            self.superieur_id.append(c.lastrowid)
        elif xml_name == 'employe':
            self.superieur_id.pop()

    def endDocument(self):
        self.conn.commit()
        self.conn.close()
            


if __name__ == '__main__':
    parser = xml.sax.make_parser()
    parser.setContentHandler(TravahoHandler())
    parser.parse(open('travaho-import.xml','r'))


